@@ -4,16 +4,86 @@ from typing import override
 from . import flags
 
 
+class WialonProfileField(enum.StrEnum):
+    """
+    Valid profile ids for Wialon objects.
+
+    `Profile field reference <https://sdk.wialon.com/wiki/en/sidebar/remoteapi/apiref/item/update_profile_field>`_.
+
+    """
+
+    VEHICLE_CLASS = "vehicle_class"
+    """`Vehicle Type <https://sdk.wialon.com/wiki/en/sidebar/remoteapi/apiref/file/type_library>`_."""
+    VIN = "vin"
+    """Vin number."""
+    REGISTRATION_PLATE = "registration_plate"
+    """Registration plate."""
+    BRAND = "brand"
+    """Brand."""
+    MODEL = "model"
+    """Model."""
+    YEAR = "year"
+    """Year."""
+    COLOR = "color"
+    """Color."""
+    ENGINE_MODEL = "engine_model"
+    """Engine model."""
+    ENGINE_POWER = "engine_power"
+    """Engine power, in kW."""
+    ENGINE_DISPLACEMENT = "engine_displacement"
+    """Engine displacement, in cm."""
+    PRIMARY_FUEL_TYPE = "primary_fuel_type"
+    """Primary fuel type."""
+    CARGO_TYPE = "cargo_type"
+    """Cargo type."""
+    CARRYING_CAPACITY = "carrying_capacity"
+    """Carrying capacity, in tons."""
+    WIDTH = "width"
+    """Width, in mm."""
+    HEIGHT = "height"
+    """Height, in mm."""
+    DEPTH = "depth"
+    """Depth, in mm."""
+    EFFECTIVE_CAPACITY = "effective_capacity"
+    """Effective capacity."""
+    GROSS_VEHICLE_WEIGHT = "gross_vehicle_weight"
+    """Gross vehicle weight."""
+    AXLES = "axles"
+    """Axles."""
+    VEHICLE_TYPE = "vehicle_type"
+    """Comment."""
+
+
 class WialonGeofenceType(enum.IntEnum):
+    """
+    A type of Wialon geofence.
+
+    `Wialon geofence type reference <https://sdk.wialon.com/wiki/en/kit/remoteapi/apiref/resource/update_zone>`_
+
+    """
+
     LINE = 1
+    """Line geofence."""
     POLYGON = 2
+    """Polygon geofence."""
     CIRCLE = 3
+    """Circular geofence."""
 
 
 class WialonMeasurementUnit(enum.IntEnum):
+    """
+    A Wialon measurement unit.
+
+    `Wialon measurement unit reference <https://sdk.wialon.com/wiki/en/local/remoteapi1904/apiref/item/update_measure_units>`_
+
+    """
+
     METRIC = 0
+    """Metric system."""
     US = 1
+    """US measurement system."""
     IMPERIAL = 2
+    """Imperial measurement system."""
 
 
 class WialonItemsType(enum.StrEnum):
@@ -25,19 +95,19 @@ class WialonItemsType(enum.StrEnum):
     """
 
     HARDWARE = "avl_hw"
-    """Hardware type."""
+    """A hardware type."""
     RESOURCE = "avl_resource"
-    """Resource."""
+    """A resource."""
     RETRANSLATOR = "avl_retranslator"
-    """Retranslator."""
+    """A retranslator."""
     ROUTE = "avl_route"
-    """Route."""
+    """A route."""
     UNIT = "avl_unit"
-    """Unit."""
+    """A unit."""
     UNIT_GROUP = "avl_unit_group"
-    """Unit group."""
+    """A unit group."""
     USER = "user"
-    """User."""
+    """A user."""
 
 
 class WialonItemProperty(enum.StrEnum):
